<?php

define('DME_BATCH_LIMIT', 5);
/**
 * @file
 * This file contains the batch related functions used only when someone
 * upgrades from earlier versions of the DME to 6.x-1.0.
 *
 * Thus the separate file to prevent it from being loaded each time.
 */

/**
 * Provides a form allowing the user to push a button and generate context tags.
 *
 * By pushing this button, you kick off the batch process that takes every node
 * and gives it a context tag in the teaser and body fields.
 */
function dme_batch_form() {
  $form = array();

  $form['description'] = array(
    '#type' => 'item',
    '#title' => t('Read This'),
    '#value' => t('This button sets off a batch process that goes through every node
    in your site and adds &lt;dme:context&gt; tags to every one of them that the dme
    uses to know which node it is processing.  These nodes will never display to your
    users, but starting this process could potentially take a while.  This is for the
    use of a site upgrading to dme 6.x-1.0 or for a site which for some reason needs
    its context regenerated.')
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Regenerate Context',
  );

  return $form;
}

function dme_batch_form_submit($form, &$form_submit) {
  $batch = array(
    'title' => t('Regenerating DME Context'),
    'operations' => array(
      array('_dme_batch_regenerate', array()),
    ),
    'finished' => '_dme_batch_complete',
    'file' => drupal_get_path('module', 'dme') .'/dme_batch.inc',
  );

  batch_set($batch);
  // according to docs, don't need the batch_process because this is form_submit.
}

/**
 * Batch function that regenerates context.
 *
 * Note that the $context['sandbox'] is used to store data on what's being done,
 * and the $context['finished'] shows a complete if it is 1.
 */
function _dme_batch_regenerate(&$context) {
  watchdog('batch', 'Starting DME Regenerate Context Batch');
  if (empty($context['sandbox'])) {
    $context['sandbox']['progress'] = 0;
    $context['sandbox']['current_node'] = 0;
    $context['sandbox']['errors'] = array();
    $context['sandbox']['max'] = db_result(db_query('SELECT COUNT(nid) FROM {node}'));

  }
  $context['results']['count'] = isset($context['results']['count']) ? $context['results']['count'] : 0;

  $result = db_query_range("SELECT nid, vid FROM {node} WHERE nid > %d ORDER BY nid", $context['sandbox']['current_node'], 0, DME_BATCH_LIMIT);
  while ($row = db_fetch_array($result)) {
    try {
      $query = "SELECT body, teaser FROM {node_revisions} nr WHERE vid = %d";
      $node_row = db_fetch_array(db_query($query, $row['vid']));
      if (!preg_match(DME_CONTEXT_REGEXP, $node_row['body'])) {
        // If this isn't set, we need to update it..
        $node_row['body'] = _dme_get_node_context_tag($row['nid']) . $node_row['body'];
        if (!preg_match(DME_CONTEXT_REGEXP, $node_row['teaser'])) {
          $node_row['teaser'] = _dme_get_node_context_tag($row['nid']) . $node_row['teaser'];
        }
        db_query("UPDATE {node_revisions} SET body = '%s' AND teaser = '%s' WHERE vid = %d",
                 $node_row['body'], $node_row['teaser'], $row['vid']);
      }

      $context['results']['count']++;
      $context['sandbox']['current_node'] = $row['nid'];
      $context['sandbox']['progress']++;
    }
    catch (Exception $ex) {
      $error_message = t(
        'An error occured while regenerating context for dme: @error in @file line @line',
        array('@error' => $ex->getMessage(),
              '@file' => $ex->getFile(),
              '@line' => $ex->getLine())
      );
      $context['sandbox']['errors'][$row['nid']] = $error_message;
      $context['results']['errors'][] = $error_message;
      watchdog('batch', $error_message, array(), WATCHDOG_ERROR, url('node/'. $row['nid']));
    }
  }

  $context['finished'] = $context['sandbox']['progress'] / $context['sandbox']['max'];
}

function _dme_batch_complete($success, $results, $operations) {
  if ($success) {
    $message = format_plural($results['count'], 'One post processed.', '@count posts processed.');
  }
  else {
    $message = t('Finished with an error.');
  }
  drupal_set_message($message);
  // Providing data for the redirected page is done through $_SESSION.

  $_SESSION['my_batch_results'] = $results;

}