<?php

/**
 * @file
 * Contains the admin form for the dme_image module.
 */

function dme_image_settings() {
  $form = array();

  $node_types = node_get_types('names');
  $fields = content_fields();
  $fields_by_type = array();
  $field_options = array(FALSE => t('No Default Field'));
  foreach ($fields as $field) {
    if ($field['type'] == 'filefield' && $field['widget']['type'] == 'imagefield_widget') {
      $types = array();
      foreach ($node_types as $type => $name) {
        if ($c_field = content_fields($field['field_name'], $type)) {
          $types[] = $name;
          $fields_by_type[$type][$field['field_name']] = $c_field;
        }
      }
      $field_options[$field['field_name']] = $field['field_name'] .' (in '. implode(', ', $types) .') ';
    }
  }

  // Get available imagecache presets.
  $presets = imagecache_presets();
  $preset_options = array(FALSE => t('No Default Preset'));
  foreach ($presets as $preset) {
    $preset_options[$preset['presetname']] = $preset['presetname'];
  }

  // Set up possible image enhancements:
  $image_display_options = array(
    'none' => 'No Display Options',
    'link' => 'Link Image to Original',
  );

  if (module_exists('lightbox2')) {
    $image_display_options['lightbox2'] = 'Display Image in Lightbox';
  }
  if (module_exists('thickbox')) {
    $image_display_options['thickbox'] = 'Display Image in Thickbox';
  }
  if (module_exists('shadowbox')) {
    $image_display_options['shadowbox'] = 'Display Image in Shadowbox';
  }
  if (module_exists('greybox')) {
    $image_display_options['greybox'] = 'Display Image in Greybox';
  }

  $form['dme_image_default_field'] = array(
    '#type' => 'select',
    '#title' => t('Select Default Image Field'),
    '#description' => t('The field you select here will be used when resolving a dme_image tag, unless you override it for a specific node type below.'),
    '#options' => $field_options,
    '#default_value' => variable_get('dme_image_default_field', FALSE),
    '#required' => TRUE,
  );

  $form['dme_image_default_preset'] = array(
    '#type' => 'select',
    '#title' => t('Select Default Imagecache Preset'),
    '#description' => t('The preset you select here will be used when resolving a dme_image tag, unless you override it for a specific node type below.'),
    '#options' => $preset_options,
    '#default_value' => variable_get('dme_image_default_preset', FALSE),
    '#required' => TRUE,
  );

  $form['dme_image_default_option'] = array(
    '#type' => 'select',
    '#title' => t('Select Default Image Display Option'),
    '#description' => t('This allows you to link to the original image, or use an enabled js module to display the image in it\'s original size on the page, such as lightbox or thickbox.'),
    '#options' => $image_display_options,
    '#default_value' => variable_get('dme_image_default_option', 'none'),
  );

  $form['dme_image_insert_css_file'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use default <em>dme_image</em> css file.'),
    '#description' => t('By default, dme_image includes a css file that defines dme-image-left, dme-image-right, and dme-image-center.  If you unselect this checkbox, this css file will not be included, and dme_image will assume that your theme will handle these classes.'),
    '#default_value' => variable_get('dme_image_insert_css_file', 1),
  );

  foreach ($node_types as $type => $name) {
    $form[$type] = array(
      '#type' => 'fieldset',
      '#title' => t('@Name Image Tag Settings', array('@Name' => $name)),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    if (count($fields_by_type[$type])) {
      $field_options = array(FALSE => t('Use Default Field'));
      foreach ($fields_by_type[$type] as $field) {
        $field_options[$field['field_name']] = $field['field_name'];
      }
      $form[$type]['dme_image_'. $type .'_field'] = array(
        '#type' => 'select',
        '#title' => t('Select @Name Image Field', array('@Name' => $name)),
        '#description' => t('The field you select here will be used when resolving a dme_image tag for @Name nodes.', array('@Name' => $name)),
        '#options' => $field_options,
        '#default_value' => variable_get('dme_image_'. $type .'_field', FALSE),
        '#required' => FALSE,
      );
      $form[$type]['dme_image_'. $type .'_preset'] = array(
        '#type' => 'select',
        '#title' => t('Select @Name Imagecache Preset', array('@Name' => $name)),
        '#description' => t('The preset you select here will be used when resolving a dme_image tag for @Name nodes.', array('@Name' => $name)),
        '#options' => $preset_options,
        '#default_value' => variable_get('dme_image_'. $type .'_preset', FALSE),
        '#required' => FALSE,
      );
    }
    else {
      $form[$type]['#description'] = t("There are no image fields defined for @Name nodes.", array('@Name' => $name));
    }
  }
  return system_settings_form($form);
}